@@ -26,7 +26,7 @@ has 'input_without_param' => (
     predicate => 'has_input_without_param'
 );
 has 'not_nullable' => ( is => 'rw', isa => 'Bool' );
-has 'init_value' => ( is => 'rw', clearer => 'clear_init_value' );
+has 'init_value' => ( is => 'rw', clearer => 'clear_init_value', predicate => 'has_init_value' );
 has 'default' => ( is => 'rw' );
 has 'default_over_obj' => ( is => 'rw', builder => 'build_default_over_obj' );
 sub build_default_over_obj { }
@@ -213,6 +213,7 @@ has 'form'      => (
     weak_ref => 1,
     predicate => 'has_form',
 );
+sub is_form { 0 }
 has 'html_name' => (
     isa     => 'Str',
     is      => 'rw',
@@ -403,7 +404,7 @@ sub element_attributes {
     push @$class, 'disabled' if $self->disabled;
     $attr->{class} = $class if @$class;
     # call form hook
-    my $mod_attr = $self->form->html_attributes($self, 'input', $attr, $result) if $self->form;
+    my $mod_attr = $self->form->html_attributes($self, 'element', $attr, $result) if $self->form;
     return ref($mod_attr) eq 'HASH' ? $mod_attr : $attr;
 }
 
@@ -709,7 +710,10 @@ sub BUILD {
 sub _result_from_fields {
     my ( $self, $result ) = @_;
 
-    if ( my @values = $self->get_default_value ) {
+    if ( $self->disabled && $self->has_init_value ) {
+        $result->_set_value($self->init_value);
+    }
+    elsif ( my @values = $self->get_default_value ) {
         if ( $self->has_inflate_default_method ) {
             @values = $self->inflate_default(@values);
         }
@@ -728,6 +732,11 @@ sub _result_from_input {
     if ($exists) {
         $result->_set_input($input);
     }
+    elsif ( $self->disabled ) {
+        # This really ought to come from _result_from_object, but there's
+        # no way to get there from here.
+        return $self->_result_from_fields( $result );
+    }
     elsif ( $self->has_input_without_param ) {
         $result->_set_input( $self->input_without_param );
     }
@@ -943,7 +952,7 @@ HTML::FormHandler::Field - base class for fields
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 SYNOPSIS
 
