@@ -10,6 +10,7 @@ use Moose::Role;
 sub _result_from_fields {
     my ( $self, $self_result ) = @_;
 
+    # defaults for compounds, etc.
     if ( my @values = $self->get_default_value ) {
         my $value = @values > 1 ? \@values : shift @values;
         if( ref $value eq 'HASH' || blessed $value ) {
@@ -18,6 +19,7 @@ sub _result_from_fields {
         $self->init_value($value)   if defined $value;
         $self_result->_set_value($value) if defined $value;
     }
+    my $my_value;
     for my $field ( $self->sorted_fields ) {
         next if ($field->inactive && !$field->_active);
         my $result = HTML::FormHandler::Field::Result->new(
@@ -25,8 +27,13 @@ sub _result_from_fields {
             parent => $self_result
         );
         $result = $field->_result_from_fields($result);
+        $my_value->{ $field->name } = $result->value if $result->has_value;
         $self_result->add_result($result) if $result;
     }
+    # setting value here to handle disabled compound fields, where we want to
+    # preserve the 'value' because the fields aren't submitted...except for the
+    # form. Not sure it's the best idea to skip for form, but it maintains previous behavior
+    $self_result->_set_value($my_value) if ( keys %$my_value );
     $self->_set_result($self_result);
     $self_result->_set_field_def($self) if $self->DOES('HTML::FormHandler::Field');
     return $self_result;
@@ -142,7 +149,7 @@ HTML::FormHandler::InitResult - internal code
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 SYNOPSIS
 
