@@ -5,10 +5,9 @@ use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my $self = shift;
-    my $result = shift || $self->result;
-    my $t;
+sub render_element {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
 
     my $output = '<button type="' . $self->input_type . '" name="'
         . $self->html_name . '" id="' . $self->id . '"';
@@ -16,10 +15,17 @@ sub render {
     $output .= '>';
     $output .= $self->_localize($self->value);
     $output .= "</button>";
+    return $output;
+}
 
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
+
 1;
 
 __END__
@@ -31,7 +37,7 @@ HTML::FormHandler::Widget::Field::ButtonTag - button field rendering widget, usi
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 AUTHOR
 
