@@ -1,13 +1,13 @@
 package HTML::FormHandler::Widget::Field::Captcha;
 # ABSTRACT: Captcha field rendering widget
-
 use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my $self = shift;
-    my $result = shift || $self->result;
+
+sub render_element {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
     return '' if $self->widget eq 'no_widget';
 
     my $output .= '<img src="' . $self->form->captcha_image_url . '"/>';
@@ -15,7 +15,13 @@ sub render {
     $output .= $self->html_name . '"';
     $output .= process_attrs($self->element_attributes);
     $output .= '/>';
+    return $output;
+}
 
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -30,7 +36,11 @@ HTML::FormHandler::Widget::Field::Captcha - Captcha field rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
+
+=head1 SYNOPSIS
+
+Renderer for Captcha field
 
 =head1 AUTHOR
 
