@@ -1,16 +1,15 @@
 package HTML::FormHandler::Widget::Field::Checkbox;
 # ABSTRACT: HTML attributes field role
-
-
 use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my $self = shift;
-    my $result = shift || $self->result;
-    my $checkbox_value = $self->checkbox_value;
 
+sub render_element {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+
+    my $checkbox_value = $self->checkbox_value;
     my $output = '<input type="checkbox" name="'
         . $self->html_name . '" id="' . $self->id . '" value="'
         . $self->html_filter($checkbox_value) . '"';
@@ -18,7 +17,14 @@ sub render {
         if $result->fif eq $checkbox_value;
     $output .= process_attrs($self->element_attributes($result));
     $output .= ' />';
-    return $self->wrap_field( $result, $output, 'wrap_label' );
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
+    return $self->wrap_field( $result, $output );
 }
 
 1;
@@ -32,7 +38,7 @@ HTML::FormHandler::Widget::Field::Checkbox - HTML attributes field role
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 SYNOPSIS
 
