@@ -1,8 +1,8 @@
 package HTML::FormHandler::Widget::Field::Compound;
 # ABSTRACT: compound field widget
-
 use Moose::Role;
 
+
 sub render_subfield {
     my ( $self, $result, $subfield ) = @_;
     my $subresult = $result->field( $subfield->name );
@@ -11,15 +11,22 @@ sub render_subfield {
     return $subfield->render( $subresult );
 }
 
-sub render {
+sub render_element {
     my ( $self, $result ) = @_;
-
     $result ||= $self->result;
+
     my $output = '';
     foreach my $subfield ( $self->sorted_fields ) {
         $output .= $self->render_subfield( $result, $subfield );
     }
     $output =~ s/^\n//; # remove newlines so they're not duplicated
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -35,7 +42,11 @@ HTML::FormHandler::Widget::Field::Compound - compound field widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
+
+=head1 SYNOPSIS
+
+Widget for rendering a compound field.
 
 =head1 AUTHOR
 
