@@ -1,13 +1,13 @@
 package HTML::FormHandler::Widget::Field::Hidden;
 # ABSTRACT: hidden field rendering widget
-
 use Moose::Role;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my ( $self, $result ) = @_;
 
+sub render_element {
+    my ( $self, $result ) = @_;
     $result ||= $self->result;
+
     my $output .= '<input type="hidden" name="';
     $output .= $self->html_name . '"';
     $output .= ' id="' . $self->id . '"';
@@ -15,12 +15,20 @@ sub render {
     $output .= process_attrs($self->element_attributes($result));
     $output .= " />";
 
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     # wrap field unless do_label is set, which would cause unwanted
     # labels to be displayed
     return $self->wrap_field( $result, $output ) if !$self->do_label;
     return $output;
 }
 
+
 use namespace::autoclean;
 1;
 
@@ -33,7 +41,11 @@ HTML::FormHandler::Widget::Field::Hidden - hidden field rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
+
+=head1 SYNOPSIS
+
+Widget for rendering a hidden field.
 
 =head1 AUTHOR
 
