@@ -1,11 +1,11 @@
 package HTML::FormHandler::Widget::Field::Password;
 # ABSTRACT: password rendering widget
-
 use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
+
+sub render_element {
     my $self = shift;
     my $result = shift || $self->result;
     my $t;
@@ -17,6 +17,13 @@ sub render {
     $output .= ' value="' . $self->html_filter($result->fif) . '"';
     $output .= process_attrs($self->element_attributes($result));
     $output .= ' />';
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -31,7 +38,11 @@ HTML::FormHandler::Widget::Field::Password - password rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
+
+=head1 SYNOPSIS
+
+Renders a password field
 
 =head1 AUTHOR
 
