@@ -1,14 +1,14 @@
 package HTML::FormHandler::Widget::Field::RadioGroup;
 # ABSTRACT: radio group rendering widget
-
-
 use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my $self = shift;
-    my $result = shift || $self->result;
+
+sub render_element {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+
     my $id = $self->id;
     my $output = '';
     $output .= "<br />" if $self->get_tag('radio_br_after');
@@ -33,6 +33,13 @@ sub render {
         $output .= '<br />' if $self->get_tag('radio_br_after');
         $index++;
     }
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -47,7 +54,7 @@ HTML::FormHandler::Widget::Field::RadioGroup - radio group rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 SYNOPSIS
 
