@@ -1,20 +1,27 @@
 package HTML::FormHandler::Widget::Field::Reset;
 # ABSTRACT: reset field rendering widget
-
 use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my ( $self, $result ) = @_;
 
+sub render_element {
+    my ( $self, $result ) = @_;
     $result ||= $self->result;
+
     my $output = '<input type="reset" name="';
     $output .= $self->html_name . '"';
     $output .= ' id="' . $self->id . '"';
     $output .= ' value="' . $self->html_filter($self->_localize($self->value)) . '"';
     $output .= process_attrs($self->element_attributes($result));
     $output .= ' />';
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -29,7 +36,11 @@ HTML::FormHandler::Widget::Field::Reset - reset field rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
+
+=head1 SYNOPSIS
+
+Renders a reset field
 
 =head1 AUTHOR
 
