@@ -5,9 +5,10 @@ use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
-    my $self = shift;
-    my $result = shift || $self->result;
+sub render_element {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+
     my $id = $self->id;
     my $index = 0;
     my $multiple = $self->multiple;
@@ -51,9 +52,17 @@ sub render {
         $index++;
     }
     $output .= '</select>';
+    return $output;
+}
+
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
+
 1;
 
 __END__
@@ -65,7 +74,7 @@ HTML::FormHandler::Widget::Field::Select - select field rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 AUTHOR
 
