@@ -5,20 +5,26 @@ use Moose::Role;
 use namespace::autoclean;
 use HTML::FormHandler::Render::Util ('process_attrs');
 
-sub render {
+sub render_element {
     my $self = shift;
     my $result = shift || $self->result;
+
     my $fif  = $self->html_filter($result->fif);
     my $id   = $self->id;
     my $cols = $self->cols || 10;
     my $rows = $self->rows || 5;
     my $name = $self->html_name;
-
     my $output =
         qq(<textarea name="$name" id="$id")
         . process_attrs($self->element_attributes($result))
         . qq( rows="$rows" cols="$cols">$fif</textarea>);
+    return $output;
+}
 
+sub render {
+    my ( $self, $result ) = @_;
+    $result ||= $self->result;
+    my $output = $self->render_element( $result );
     return $self->wrap_field( $result, $output );
 }
 
@@ -33,7 +39,7 @@ HTML::FormHandler::Widget::Field::Textarea - textarea rendering widget
 
 =head1 VERSION
 
-version 0.40006
+version 0.40007
 
 =head1 AUTHOR
 
